﻿#pragma strict

var go:GameObject;
private var gameover:boolean = false;
private var maxHeight:int = 2;
private var maxWidth:int = 2;
private var maxLevel:int = 2;
private var cursor:GameObject;
private var color:ColorScript;
private var grid:GameObject;

private var level:int = 0;

public var colors:Material[];
public var cam:Camera;
private var viewWidth:float = 0.65f;
private var compGrid:GameObject;
private var timer:TimerScript;
private var finishedFont:TextMesh;
public var score:ScoreScript;

function Start () {
	cursor = GameObject.Instantiate(go);
	grid = GameObject.Find("Grid");
	color = GameObject.Find("ColorChooser").GetComponent(ColorScript);
	compGrid = GameObject.Find("BaseGrid");
	timer = GameObject.Find("Timer").GetComponent(TimerScript);

	finishedFont = GameObject.Find("FinishedFont").GetComponent(TextMesh);
	
	LoadLevel();
	GenerateBaseGrid();
	GenerateBaseCompGrid();
	
	var size:int = maxHeight;
	if (maxWidth > maxHeight) {
		size = maxWidth;
	}
	cam.orthographicSize = (size + 10) / 2.0f;
}

private var modifierCamera:float = 0.0f;
private var lastPos:Vector2 = new Vector2(1000,1000);
private var framePassed:boolean = false;
function Update () {
	if (Input.GetKeyDown(KeyCode.R)) {
		Application.LoadLevel("Main");
	}
	else if (Input.GetKeyDown(KeyCode.Escape)) {
		Application.LoadLevel("Levels");
	}

	grid.transform.position.y = level * -1;
	compGrid.transform.position.y = grid.transform.position.y;

	modifierCamera = cam.orthographicSize * 2.0f / Screen.height;
	
	if (!gameover) {
		var gridPos:Vector2 = mouseToGrid();
		gridPos.x = Mathf.Clamp(gridPos.x, (maxWidth-1) * -1, (maxWidth-1));
		gridPos.y = Mathf.Clamp(gridPos.y, (maxHeight-1) * -1, (maxHeight-1));
		if (lastPos == new Vector2(1000,1000)) {
			lastPos = gridPos;
		}
		cursor.transform.position.x = gridPos.x;
		cursor.transform.position.y = 0.1;
		cursor.transform.position.z = gridPos.y;
		
		if (Input.GetMouseButton(0) && !(Input.GetKey(KeyCode.LeftShift) || Input.GetKey(KeyCode.RightShift))) {
			var firstDone:boolean = false;
			while (!(firstDone && gridPos == lastPos)) {
				if (gridPos.x < lastPos.x) {
					lastPos.x -= 1.0f;
				}
				else if (gridPos.x > lastPos.x) {
					lastPos.x += 1.0f;
				}
				
				if (gridPos.y < lastPos.y) {
					lastPos.y -= 1.0f;
				}
				else if (gridPos.y > lastPos.y) {
					lastPos.y += 1.0f;
				}
				
				var exists:GameObject = GameObject.Find("Cube " + lastPos.x.ToString() + "," + level + "," + lastPos.y.ToString());
				
				if (exists == null && color.selectedColor != 6) {
					addCube(lastPos, color.selectedColor);				
				}
				else if (exists != null && color.selectedColor == 6) {
					deleteCube(exists);
				}
				else if (exists != null) {
					exists.renderer.material = colors[color.selectedColor - 1];
				}
				
				firstDone = true;
			}
		}
		else if (Input.GetMouseButton(0) && (Input.GetKey(KeyCode.LeftShift) || Input.GetKey(KeyCode.RightShift))) {
			var firstDone1:boolean = false;
			while (!(firstDone1 && gridPos == lastPos)) {
				if (gridPos.x < lastPos.x) {
					lastPos.x -= 1.0f;
				}
				else if (gridPos.x > lastPos.x) {
					lastPos.x += 1.0f;
				}
				
				if (gridPos.y < lastPos.y) {
					lastPos.y -= 1.0f;
				}
				else if (gridPos.y > lastPos.y) {
					lastPos.y += 1.0f;
				}
				
				var exists1:GameObject = GameObject.Find("Cube " + lastPos.x.ToString() + "," + level + "," + lastPos.y.ToString());
				
				if (exists1 != null) {
					deleteCube(exists1);
				}
				
				firstDone1 = true;
			}
		}
		else {
			lastPos = gridPos;
		}
	}
	else {
		
	
		if (Input.GetKeyDown(KeyCode.Return) && framePassed) {
			var curLvl:int = PlayerPrefs.GetInt("CurrentLevel",1);
			PlayerPrefs.SetInt("CurrentLevel", curLvl+1);
			
			if (curLvl == 10) {
				Application.LoadLevel("Levels");
			}
			else {
				Application.LoadLevel("Main");
			}
		}
		
		framePassed = true;
	}
}

function mouseToGrid():Vector2 {
	var v2:Vector2 = new Vector2();
	v2.x = Mathf.Round((Input.mousePosition.x - Screen.width * (1-viewWidth) - (Screen.width - Screen.width * (1-viewWidth)) / 2.0f) * modifierCamera);
	v2.y = Mathf.Round((Input.mousePosition.y - Screen.height / 2.0f) * modifierCamera);
	return v2;
}

function addCube(v2:Vector2, selectedColor:int) {
	var newThing:GameObject = GameObject.Instantiate(go);
	newThing.transform.position = new Vector3(v2.x, 0.0f, v2.y);
	newThing.transform.parent = grid.transform;
	newThing.transform.name = "Cube " + v2.x.ToString() + "," + level + "," + v2.y.ToString();
	newThing.tag = "Cube";
	newThing.renderer.material = colors[selectedColor-1];
}

function deleteCube(go:GameObject) {
	Destroy(GameObject.Find("Vector " + go.name));
	Destroy(go);
}

function CreateBaseCube(j:int, k:int) {
	var newThing:GameObject = GameObject.Instantiate(go);
	newThing.transform.position = new Vector3(j, -1f, k);
	newThing.transform.parent = grid.transform;
	newThing.transform.name = "Base " + j.ToString() + ",-1," + k.ToString();
	newThing.renderer.material = colors[5];
}

function CreateBaseCompCube(j:int, k:int) {
	var newThing:GameObject = GameObject.Instantiate(go);
	newThing.transform.position = new Vector3(j+2000, -1f, k);
	newThing.transform.parent = compGrid.transform;
	newThing.transform.name = "Base " + j.ToString() + ",-1," + k.ToString();
	newThing.renderer.material = colors[5];
}

function GenerateBaseGrid() {
	for (var j:int = 0;j<=maxWidth;j++) {
		for (var k:int = 0;k<=maxHeight;k++) {
			CreateBaseCube(j,k);
			if (j != 0) {
				CreateBaseCube(-1 * j,k);
			}
			if (k != 0) {
				CreateBaseCube(j,-1 * k);
			}
			if (j !=0 && k != 0) {
				CreateBaseCube(-1 * j,-1 * k);
			}
		}
	}
}

function addCube(v3:Vector3, selectedColor:int) {
	var newThing:GameObject = GameObject.Instantiate(go);
	newThing.transform.localPosition = new Vector3(v3.x + 2000, v3.y, v3.z);
	newThing.transform.parent = compGrid.transform;
	newThing.transform.name = "User " + v3.x.ToString() + "," + level + "," + v3.y.ToString();
	newThing.renderer.material = colors[selectedColor-1];
}

function GenerateBaseCompGrid() {
	for (var j:int = 0;j<=maxWidth;j++) {
		for (var k:int = 0;k<=maxHeight;k++) {
			CreateBaseCompCube(j,k);
			if (j != 0) {
				CreateBaseCompCube(-1 * j,k);
			}
			if (k != 0) {
				CreateBaseCompCube(j,-1 * k);
			}
			if (j !=0 && k != 0) {
				CreateBaseCompCube(-1 * j,-1 * k);
			}
		}
	}
}

function GetLevelText():String {
	var list:ArrayList = GetStringList();
	var level:String = "";
	
	for (var x:Object in list) {
		list.Add(x.ToString());
		level += x.ToString() + "/";
	}
	
	return level;
}

function GetStringList():ArrayList {
	var gos:GameObject[] = GameObject.FindGameObjectsWithTag("Cube");
	var list:ArrayList = new ArrayList();
	
	for (var j:int = 0; j<gos.length; j++) {
		list.Add(GetCubeString(gos[j]));
	}
	
	return list;
}

function GetCubeString(go:GameObject):String {
	return go.transform.name.Replace("Cube ", "")+","+GetColorNumber(go).ToString();
}

function GetColorNumber(go:GameObject):int {
	if (go.renderer.material.mainTexture == colors[0].mainTexture) return 1;
	if (go.renderer.material.mainTexture == colors[1].mainTexture) return 2;
	if (go.renderer.material.mainTexture == colors[2].mainTexture) return 3;
	if (go.renderer.material.mainTexture == colors[3].mainTexture) return 4;
	if (go.renderer.material.mainTexture == colors[4].mainTexture) return 5;
	return 6;
}

private var compareLevel:ArrayList;
private var actualLevel:ArrayList;
function LoadLevel() {
	var level:int = PlayerPrefs.GetInt("CurrentLevel",1);
	
	var lvl:String;
	
	if (level == 1) {
		//Box
		maxHeight = 2;
		maxWidth = 2;
		maxLevel = 3;
		
		lvl = "-1,0,1,1/-1,0,0,1/-1,0,-1,1/0,0,-1,1/1,0,-1,1/1,0,0,1/1,0,1,1/0,0,1,1/0,0,0,1/-1,1,1,1/-1,1,0,1/-1,1,-1,1/0,1,-1,1/1,1,-1,1/1,1,0,1/1,1,1,1/0,1,1,1/0,1,0,1/-1,2,1,1/-1,2,0,1/-1,2,-1,1/0,2,-1,1/1,2,-1,1/1,2,0,1/1,2,1,1/0,2,1,1/0,2,0,1";
	}
	else if (level == 2) {
		//Coin
		maxHeight = 2;
		maxWidth = 3;
		maxLevel = 6;
		
		lvl = "-1,0,1,4/-1,0,0,4/-1,0,-1,4/0,0,-1,4/1,0,-1,4/1,0,0,4/1,0,1,4/0,0,1,4/0,0,0,4/-2,1,1,4/-2,1,0,4/-2,1,-1,4/-1,1,-1,4/0,1,-1,4/1,1,-1,4/2,1,-1,4/2,1,0,4/2,1,1,4/1,1,1,4/0,1,1,4/-1,1,1,4/-1,1,0,4/0,1,0,4/1,1,0,4/-2,2,1,4/-2,2,0,4/-2,2,-1,4/-1,2,-1,4/0,2,-1,4/1,2,-1,4/2,2,-1,4/2,2,0,4/2,2,1,4/1,2,1,4/0,2,1,4/-1,2,1,4/-1,2,0,4/0,2,0,4/1,2,0,4/-2,3,1,4/-2,3,0,4/-2,3,-1,4/-1,3,-1,4/0,3,-1,4/1,3,-1,4/2,3,-1,4/2,3,0,4/2,3,1,4/1,3,1,4/0,3,1,4/-1,3,1,4/-1,3,0,4/0,3,0,4/-2,4,1,4/-2,4,0,4/-2,4,-1,4/-1,4,-1,4/0,4,-1,4/1,4,-1,4/2,4,-1,4/2,4,0,4/2,4,1,4/1,4,1,4/0,4,1,4/-1,4,1,4/-1,4,0,4/0,4,0,4/1,4,0,4/-1,5,1,4/-1,5,0,4/-1,5,-1,4/0,5,-1,4/1,5,-1,4/1,5,0,4/1,5,1,4/0,5,1,4/0,5,0,4/1,3,0,4";
	}
	else if (level == 3) {
		//Chair
		maxHeight = 2;
		maxWidth = 2;
		maxLevel = 6;
		lvl = "-1,0,1,5/1,0,1,5/-1,0,-1,5/1,0,-1,5/-1,1,1,5/1,1,1,5/-1,1,-1,5/1,1,-1,5/-1,2,1,5/-1,2,0,5/-1,2,-1,5/0,2,-1,5/1,2,-1,5/1,2,1,5/0,2,1,5/0,2,0,5/1,2,0,5/0,3,1,5/-1,4,1,5/0,4,1,5/1,4,1,5/-1,3,1,5/1,3,1,5/-1,5,1,5/0,5,1,5/1,5,1,5";
	}
	else if (level == 4) {
		//Heart
		maxHeight = 2;
		maxWidth = 4;
		maxLevel = 7;
		
		lvl = "0,0,1,1/0,0,0,1/0,0,-1,1/-1,1,1,1/-1,1,0,1/-1,1,-1,1/0,1,-1,1/";
		lvl += "1,1,-1,1/1,1,0,1/1,1,1,1/0,1,1,1/0,1,0,1/-2,2,1,1/-2,2,0,1/-2,2,-1,1/";
		lvl += "-1,2,-1,1/0,2,-1,1/1,2,-1,1/2,2,-1,1/2,2,0,1/2,2,1,1/1,2,1,1/0,2,1,1/";
		lvl += "-1,2,1,1/-1,2,0,1/0,2,0,1/1,2,0,1/-2,4,1,1/-2,4,-1,1/-1,4,-1,1/-1,4,1,1/";
		lvl += "1,4,1,1/1,4,-1,1/2,4,-1,1/2,4,1,1/-2,3,1,1/-3,3,1,1/-3,3,0,1/-3,3,-1,1/";
		lvl += "-2,3,-1,1/-1,3,-1,1/0,3,-1,1/1,3,-1,1/2,3,-1,1/3,3,-1,1/3,3,0,1/3,3,1,1/";
		lvl += "2,3,1,1/1,3,1,1/0,3,1,1/-1,3,1,1/-2,3,0,1/-1,3,0,1/0,3,0,1/1,3,0,1/2,3,0,1/";
		lvl += "-3,4,1,1/-3,4,0,1/-3,4,-1,1/0,4,-1,1/3,4,-1,1/3,4,0,1/3,4,1,1/0,4,1,1/";
		lvl += "-2,4,0,1/-1,4,0,1/0,4,0,1/1,4,0,1/2,4,0,1/-3,5,1,1/-3,5,0,1/-3,5,-1,1/";
		lvl += "-2,5,-1,1/-1,5,-1,1/0,5,-1,1/1,5,-1,1/2,5,-1,1/3,5,-1,1/3,5,0,1/3,5,1,1/";
		lvl += "2,5,1,1/1,5,1,1/0,5,1,1/-1,5,1,1/-2,5,1,1/-2,5,0,1/-1,5,0,1/0,5,0,1/1,5,0,1/";
		lvl += "2,5,0,1/-2,6,1,1/-2,6,0,1/-2,6,-1,1/-1,6,-1,1/-1,6,0,1/-1,6,1,1/1,6,1,1/2,6,1,1/";
		lvl += "2,6,0,1/1,6,0,1/1,6,-1,1/2,6,-1,1";
	}
	else if (level == 5) {
		//Stairs
		maxHeight = 2;
		maxWidth = 2;
		maxLevel = 3;
	
		lvl = "-1,0,1,1/-1,0,0,1/-1,0,-1,1/0,0,-1,1/1,0,-1,1/1,0,0,1/1,0,1,1/0,0,1,1/0,0,0,1/1,1,0,2/0,1,0,2/-1,1,0,2/-1,1,1,2/0,1,1,2/1,1,1,2/-1,2,1,3/0,2,1,3/1,2,1,3";
	}
	else if (level == 6) {
		//Flower
		maxHeight = 2;
		maxWidth = 2;
		maxLevel = 6;
	
		lvl = "0,0,0,2/0,1,0,2/0,2,0,2/1,1,0,2/-1,1,0,2/-1,5,-1,4/0,5,-1,4/1,5,-1,4/-1,4,-1,4/0,4,-1,5/1,4,-1,4/-1,3,-1,4/0,3,-1,4/1,3,-1,4/0,3,0,2/0,4,0,2";
	}
	else if (level == 7) {
		//Tree
		maxHeight = 4;
		maxWidth = 4;
		maxLevel = 9;
	
		lvl = "-1,0,0,5/1,0,0,5/0,0,0,5/0,0,-1,5/0,0,1,5/-1,1,0,5/0,1,-1,5/1,1,0,5/0,1,1,5/0,1,0,5/0,2,3,2/0,2,2,2/0,2,1,2/0,2,0,2/0,2,-1,2/0,2,-2,2/0,2,-3,2/-3,2,0,2/-2,2,0,2/-1,2,0,2/1,2,0,2/2,2,0,2/3,2,0,2/-1,2,2,2/-1,2,1,2/-2,2,1,2/-2,2,-1,2/-1,2,-1,2/-1,2,-2,2/1,2,-2,2/1,2,-1,2/2,2,-1,2/1,2,1,2/2,2,1,2/1,2,2,2/0,3,2,2/0,3,1,2/0,3,0,2/0,3,-1,2/0,3,-2,2/-2,3,0,2/-1,3,0,2/1,3,0,2/2,3,0,2/1,3,1,2/1,3,-1,2/-1,3,1,2/-1,3,-1,2/0,4,2,2/0,4,1,2/0,4,0,2/0,4,-1,2/0,4,-2,2/-2,4,0,2/-1,4,0,2/1,4,0,2/2,4,0,2/1,4,1,2/1,4,-1,2/-1,4,-1,2/-1,4,1,2/0,5,1,2/0,5,0,2/0,5,-1,2/-1,5,0,2/1,5,0,2/0,6,1,2/0,6,0,2/0,6,-1,2/-1,6,0,2/1,6,0,2/0,7,0,2/0,8,0,2";
	}
	else if (level == 8) {
		//House
		maxHeight = 3;
		maxWidth = 4;
		maxLevel = 7;
	
		lvl = "-2,0,1,1/-1,0,1,1/0,0,1,1/1,0,-2,1/1,0,-1,1/1,0,0,1/1,0,1,1/1,0,2,1/0,0,2,1/-1,0,2,1/-2,0,2,1/-3,0,2,1/2,0,2,1/2,0,1,1/2,0,0,1/2,0,-1,1/2,0,-2,1/3,0,-2,1/3,0,-1,1/3,0,0,1/3,0,2,1/-3,0,-2,1/-2,0,-2,5/-1,0,-2,5/0,0,-2,1/-3,0,1,1/-3,0,0,1/-3,0,-1,1/-2,0,-1,1/-1,0,-1,1/0,0,-1,1/0,0,0,1/3,0,1,1/-1,0,0,1/-2,0,0,1/-3,1,2,1/-2,1,2,1/-1,1,2,1/0,1,2,1/1,1,2,1/2,1,2,1/3,1,2,1/3,1,-2,1/2,1,-2,3/1,1,-2,3/0,1,-2,1/-1,1,-2,5/-2,1,-2,5/-3,1,-2,1/-3,1,1,1/-2,1,1,1/-1,1,1,1/0,1,1,1/1,1,1,1/2,1,1,1/3,1,1,1/3,1,0,1/3,1,-1,1/2,1,-1,1/1,1,-1,1/0,1,-1,1/-1,1,-1,1/-2,1,-1,1/-3,1,-1,1/-3,1,0,1/-2,1,0,1/-1,1,0,1/0,1,0,1/1,1,0,1/2,1,0,1/-1,2,-2,5/0,2,-2,1/1,2,-2,3/-2,2,-2,5/-3,2,-2,1/-3,2,2,1/-2,2,2,1/-1,2,2,1/0,2,2,1/1,2,2,1/2,2,2,1/3,2,2,1/3,2,-2,1/2,2,-2,3/2,2,-1,1/2,2,0,1/2,2,1,1/3,2,1,1/3,2,0,1/3,2,-1,1/1,2,-1,1/0,2,-1,1/-1,2,-1,1/-2,2,-1,1/-3,2,-1,1/-3,2,0,1/-2,2,0,1/-1,2,0,1/0,2,0,1/1,2,0,1/1,2,1,1/0,2,1,1/-1,2,1,1/-2,2,1,1/-3,2,1,1/-1,3,-1,1/3,3,2,1/2,3,2,1/1,3,2,1/0,3,2,1/-1,3,2,1/-2,3,2,1/-3,3,1,1/-3,3,2,1/-3,3,0,1/-3,3,-1,1/-2,3,-1,1/3,3,0,1/3,3,1,1/2,3,1,1/1,3,1,1/0,3,0,1/-1,3,0,1/-2,3,0,1/-2,3,1,1/-1,3,1,1/0,3,1,1/2,3,0,1/1,3,0,1/0,3,-1,1/3,3,-1,1/2,3,-1,1/1,3,-1,1/-3,3,-2,1/-2,3,-2,1/-1,3,-2,1/0,3,-2,1/1,3,-2,1/2,3,-2,1/3,3,-2,1/-3,4,0,5/-3,4,-1,5/-3,4,-2,5/-2,4,-2,5/-1,4,-2,5/0,4,-2,5/1,4,-2,5/2,4,-2,5/3,4,-2,5/-3,4,2,5/-2,4,2,5/-1,4,2,5/0,4,2,5/1,4,2,5/2,4,2,5/3,4,2,5/3,4,1,5/3,4,0,5/3,4,-1,5/2,4,-1,5/1,4,-1,5/-1,4,-1,5/-2,4,-1,5/-2,4,0,5/-2,4,1,5/-3,4,1,5/-1,4,1,5/0,4,1,5/1,4,1,5/2,4,1,5/2,4,0,5/1,4,0,5/0,4,0,5/-1,4,0,5/0,4,-1,5/-3,5,1,5/-2,5,1,5/-1,5,1,5/0,5,1,5/1,5,1,5/2,5,1,5/3,5,1,5/-3,5,0,5/-2,5,0,5/-1,5,0,5/0,5,0,5/1,5,0,5/2,5,0,5/3,5,0,5/-3,5,-1,5/-2,5,-1,5/-1,5,-1,5/0,5,-1,5/1,5,-1,5/2,5,-1,5/3,5,-1,5/-3,6,0,5/-2,6,0,5/-1,6,0,5/0,6,0,5/1,6,0,5/2,6,0,5/3,6,0,5";
	}
	else if (level == 9) {
		//Spiral
		maxHeight = 4;
		maxWidth = 4;
		maxLevel = 1;
	
		lvl = "-3,0,3,2/-3,0,2,2/-3,0,1,2/-3,0,0,2/-3,0,-1,2/-3,0,-2,2/-3,0,-3,2/-2,0,-3,2/-1,0,-3,2/0,0,-3,2/1,0,-3,2/2,0,-3,2/3,0,-3,2/3,0,-2,2/3,0,-1,2/3,0,0,2/3,0,1,2/3,0,2,2/3,0,3,2/2,0,3,2/1,0,3,2/0,0,3,2/-1,0,3,2/-2,0,3,3/-1,0,2,2/-1,0,1,2/-1,0,0,2/-1,0,-1,2/0,0,-1,2/1,0,-1,2/1,0,0,2/1,0,1,2/-2,0,2,3/-2,0,1,3/-2,0,0,3/-2,0,-1,3/-2,0,-2,3/-1,0,-2,3/0,0,-2,3/1,0,-2,3/2,0,-2,3/2,0,-1,3/2,0,0,3/2,0,1,3/2,0,2,3/1,0,2,3/0,0,2,3/0,0,1,3/0,0,0,3";
	}
	else if (level == 10) {
		//Lizard
		maxHeight = 3;
		maxWidth = 6;
		maxLevel = 5;
	
		lvl = "1,0,0,2/1,0,-2,2/-2,0,0,2/-2,0,-2,2/3,1,0,2/3,1,-1,2/3,1,-2,2/2,1,-2,2/2,1,-1,2/2,1,0,2/1,1,0,2/0,1,0,2/-1,1,0,2/-2,1,0,2/-3,1,-1,2/-2,1,-2,2/-2,1,-1,2/-1,1,-2,2/0,1,-2,2/0,1,-1,2/1,1,-1,2/-1,1,-1,2/1,1,-2,2/1,2,-2,2/1,2,-1,2/1,2,0,2/0,2,0,2/0,2,-1,2/0,2,-2,2/-1,2,-2,2/-2,2,-2,2/-1,2,0,2/-1,2,-1,2/-2,2,-1,2/-3,2,-1,2/-2,2,0,2/-4,2,-1,2/1,3,0,2/1,3,-1,2/1,3,-2,2/2,3,-2,2/2,3,-1,2/2,3,0,2/3,3,0,2/3,3,-1,2/3,3,-2,2/2,2,-1,1/2,2,0,1/3,2,-1,1/4,2,-1,1/5,2,-1,1/-3,1,0,2/-3,2,0,2/-4,2,0,2/-5,2,0,2/-5,2,1,2/-5,2,2,2/-4,2,1,2/2,4,-1,2/2,4,-2,3/2,4,0,3/1,4,0,2/1,4,-1,2/1,4,-2,2/2,2,-2,1";
	}
	
	compareLevel = CreateLevel(lvl);
}

function CreateLevel(lvl:String):ArrayList {
	var list:ArrayList = new ArrayList();
	
	for (var c:String in lvl.Split("/"[0])) {
		var v:String[] = c.Split(","[0]);
		list.Add(c);
		addCube(new Vector3(parseInt(v[0]),parseInt(v[1]),parseInt(v[2])), parseInt(v[3]));
	}
	
	return list;
}

function NextLayer() {
	if (level + 1 >= maxLevel) {
		gameover = true;
		
		score.show = true;
		finishedFont.text = finishedFont.text.Replace("[SCORE]", GetScore());
		cursor.transform.position = new Vector3(0,0,5000);
	}
	else {
		level += 1;
		timer.StartTimer();
	}
}

function GetScore():String {
	actualLevel = GetStringList();
	
	var numWrong:int = 0;
	
	for (var j:Object in actualLevel) {
		if (!compareLevel.Contains(j.ToString())) {
			numWrong+=1;
			RemoveStringStartingWith(j.ToString().Substring(0,j.ToString().Length - 2));
		}
	}
	
	for (var k:Object in compareLevel) {
		if (!actualLevel.Contains(k.ToString())) {
			numWrong+=1;
		}
	}
	
	var total:float = ((maxHeight-1) * 2 + 1) * ((maxWidth-1) * 2 + 1) * maxLevel;
	
	var perc:float = (total - numWrong) / (total * 1.0f) * 100.0f;
	
	var oldScore:float = PlayerPrefs.GetFloat("Score" + PlayerPrefs.GetInt("CurrentLevel",1).ToString(),0);
	if (oldScore <= perc) {
		PlayerPrefs.SetFloat("Score" + PlayerPrefs.GetInt("CurrentLevel",1).ToString(), Mathf.Round(perc * 100) / 100);
	}

	return (Mathf.Round(perc * 100) / 100).ToString() + " %";
}

function RemoveStringStartingWith(str:String) {
	for (var l:Object in compareLevel) {
		if (l.ToString().StartsWith(str)) {
			compareLevel.Remove(l);
			return;
		}
	}
}